==> vokoscreen_1.9.6.orig.tar.gz: vokoscreen-1.9.6/language/vokoscreen_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>أرسل آخر فيديو</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>أرسل ملفات فيديو محددة</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>أرسل</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>سوف تجد الفيديو على شكل رابط</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>اختر ملفاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>بدون حاشية</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>حاشية</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>كاميرا الوب</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>الجهاز مشغول حاليا</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>اِختر كاميرا</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>نافذة</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>افتراضي</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>الكوديك</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>لا تسجل مؤشر الفأرة</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>مسار الفيديو</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>المشغّل</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>تصغير البرنامج عند بدء التسجيل</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>أرسل</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>مدة التسجيل</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>الحجم بالكيلوبايت</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>أبعاد نافذة التسجيل</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>الصيغة</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>إعدادات fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>افتح الدليل</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>عدّ تنازلي</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>شغّل آخر ملف فيديو</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>أرسل الفيديو</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>عدد المشاهد \ ثا الحالية</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>الجهاز %1 مشغول حالياً</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>عدد المشاهد الحالية في الإعدادات كبير جداً</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>واصِل</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحة البرنامج</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>القائمة البريدية</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>الدعم</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>المطور</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>المشاهد</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>نسخة تجريبية openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>نسخة تجريبية Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>برنامج التسجيل</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>الترجمات</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>الملف المصدري</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>أظهِر البرنامج في مساحة التبليغ</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.2.0.orig.tar.gz: vokoscreen-2.2.0/language/vokoscreen_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>الجهاز مشغول حاليا</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>مجهول</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>مستخدمة من طرف</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>أرسل آخر فيديو</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>أرسل ملفات فيديو محددة</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>أرسل</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغِ</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>الرجاء تنصيب مشغل فيديو</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>سوف تجد الفيديو على شكل رابط</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>اختر ملفاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>حاشية</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>آظهِر في وضع ملء الشاشة</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>اُنقر باليمين لإظهار القائمة</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>معرَّفات المستخدم</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>الجهاز مشغول حاليا</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>مستخدمة من طرف</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>مجهول</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>نافذة</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>افتراضي</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>الكوديك</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>لا تسجل مؤشر الفأرة</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>مسار الفيديو</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>المشغّل</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>تصغير البرنامج عند بدء التسجيل</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>أرسل</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>مدة التسجيل</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>الحجم بالكيلوبايت</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>أبعاد نافذة التسجيل</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>الصيغة</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>إعدادات fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>افتح الدليل</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>عدّ تنازلي</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>شغّل آخر ملف فيديو</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>أرسل الفيديو</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>عدد المشاهد \ ثا الحالية</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>واصِل</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحة البرنامج</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>الدعم</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>المطور</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>المشاهد</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>برنامج التسجيل</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>الترجمات</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>الملف المصدري</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>أظهِر البرنامج في مساحة التبليغ</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>نسخة جديدة متوفرة</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>ترميز الفيديو</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>ترميز الصوت</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>كاميرا الوب</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>اِختر كاميرا</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>معكوس</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>الشاشة</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>جميع الشاشات</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>صفحة المطوّر</translation>
    </message>
</context>
</TS>
